AddPackageRunner class

Runner that orchestrates adding a new package to an existing workspace.

Constructors

AddPackageRunner({required FileSystem fs, required ProcessRunner runner, void log(String) = print})

Properties

fs → FileSystem
final
hashCode int
The hash code for this object.
no setterinherited
log → void Function(String)
final
runner ProcessRunner
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run(List<String> arguments) → void
Runs the add-package workflow.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited