ProcessRunnerResult class

Simple result class for ProcessRunner.

Constructors

ProcessRunnerResult({required int exitCode, required dynamic stdout, required dynamic stderr})

Properties

exitCode int
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stderr → dynamic
final
stdout → dynamic
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited