WorkspaceProcess class abstract

Utilities for creating and configuring a Flutter workspace directory.

This class provides synchronous helpers used by the CLI to scaffold a workspace, create package folders, add common dependencies, and resolve workspace dependencies.

Constructors

WorkspaceProcess()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

addingFlutterDependenciesSync() → void
Adds common runtime Flutter dependencies to the workspace pubspec.
addingFlutterDevDependenciesSync() → void
Adds development dependencies (linting) to the workspace pubspec.
createPackagesFolderSync() → void
Creates the packages folder used for shared packages.
createRootPubspecSync({required String dartVersion, required String projectName}) → void
Writes the workspace root pubspec.yaml with basic configuration.
createWorkspaceFolderSync({required String projectName}) → void
Creates <name>_workspaces and changes the current working directory.
moveConfigsToWorkspaceRootSync({required String projectName, required Directory initialDirectory}) → void
Moves configuration files from the Flutter app folder to the workspace root.
runningFlutterPubGetSync() → void
Runs flutter pub get at the current working directory to resolve dependencies.