CorePackageProcess class abstract
Helpers to create and configure the shared core package inside packages/.
Contains synchronous helpers that scaffold a package and write a
workspace-oriented pubspec.yaml for the core package.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
createCorePackageSync(
) → void -
Creates
packages/coreby running the Flutter package template. -
updateCorePubspecSync(
{required String dartVersion}) → void -
Writes
packages/core/pubspec.yamlconfigured for workspace resolution.