DartProcess class
Utilities for querying and validating the installed Dart SDK.
Provides synchronous helpers used by the CLI to detect the locally installed Dart SDK version and to enforce a minimum required SDK.
Constructors
- DartProcess({required ProcessRunner runner, void log(String) = print})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- log → void Function(String)
-
final
- runner → ProcessRunner
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getDartVersionSync(
) → String - Returns the installed Dart SDK version string or a sensible fallback.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited