PackageProcess class
Helpers to create and configure a new package inside packages/.
Constructors
- PackageProcess({required FileSystem fs, required ProcessRunner runner, void log(String) = print})
Properties
- fs → FileSystem
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- log → void Function(String)
-
final
- runner → ProcessRunner
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createPackageSync(
{required String packageName}) → void -
Creates a package in
packages/by running the Flutter package template. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
updatePubspecSync(
{required String packageName, required String dartVersion}) → void -
Writes
packages/[packageName]/pubspec.yamlconfigured for workspace resolution.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited