ProjectNameProcess class

Helpers for extracting and validating the --name CLI argument.

The CLI expects a required --name (-n) option that specifies the project/workspace base name used throughout the scaffolding process.

Constructors

ProjectNameProcess({void log(String) = print})

Properties

hashCode int
The hash code for this object.
no setterinherited
log → void Function(String)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getProjectName({required List<String> arguments}) String
Parses arguments for the required --name option and returns it.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited